"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const whitespace_1 = require("./whitespace");
const allWords = /\w+/g;
const wordsSplitChars = /(\.|,|\?| |-|!)/gm;
function specificWordCount(str, word, strict) {
    const strSplit = str.split(wordsSplitChars);
    const cleaned = strSplit.filter(t => {
        return allWords.test(t);
    });
    const counted = cleaned.filter(w => {
        const num = !isNaN(parseFloat(w));
        if (num) {
            return false;
        }
        else if (strict) {
            return word === w;
        }
        else {
            return word.toLowerCase() === w.toLowerCase();
        }
    });
    return counted ? counted.length : 0;
}
function wordCount(str) {
    const strSplit = str.split(wordsSplitChars);
    const cleaned = strSplit.filter(t => {
        return allWords.test(t);
    });
    if (cleaned && cleaned.length) {
        const counted = cleaned.filter(w => {
            return isNaN(parseFloat(w));
        });
        return counted && counted.length ? counted.length : 0;
    }
    return 0;
}
function allWordCount(str, strict) {
    const strSplit = whitespace_1.whitespace
        .replaceWith(str, { tabs: true, breaks: true, multiSpace: true }, ' ')
        .split(wordsSplitChars);
    if (strSplit && strSplit.length) {
        const cleaned = strSplit.filter(t => {
            return allWords.test(t);
        });
        if (cleaned && cleaned.length) {
            return cleaned.reduce((acc, word) => {
                if (strict) {
                    if (acc[word]) {
                        acc[word] += 1;
                    }
                    else {
                        acc[word] = 1;
                    }
                }
                else {
                    const lower = word.toLowerCase();
                    if (acc[lower]) {
                        acc[lower] += 1;
                    }
                    else {
                        acc[lower] = 1;
                    }
                }
                return acc;
            }, {});
        }
        else {
            return {};
        }
    }
    else {
        return {};
    }
}
const words = {
    allWordCount,
    specificWordCount,
    wordCount
};
exports.words = words;
